@@ -24,146 +24,8 @@ import uproot3
 from logzero import logger as log
 
 from . import utils
-
-tuple_names = {
-    "Pi": ["DSt_PiMTuple", "DSt_PiPTuple"],
-    "K": ["DSt_KPTuple", "DSt_KMTuple"],
-    "Mu": ["Jpsi_MuPTuple", "Jpsi_MuMTuple"],
-    "K_DsPhi": ["DsPhi_KPTuple", "DsPhi_KMTuple"],
-    "K_DSt3Pi": ["DSt3Pi_KPTuple", "DSt3Pi_KMTuple"],
-    "Pi_DSt3Pi": ["DSt3Pi_PiMTuple", "DSt3Pi_PiPTuple"],
-    "K_Phi": ["Phi_KMTuple", "Phi_KPTuple"],
-    "K_Omega": ["OmegaL_KPTuple", "OmegaL_KMTuple"],
-    "K_DD": ["OmegaDDD_KPTuple", "OmegaDDD_KMTuple"],
-    "Pi_KS": ["KSLL_PiPTuple", "KSLL_PiMTuple"],
-    "Pi_DD": ["KSDD_PiPTuple", "KSDD_PiMTuple"],
-    "P": [
-        "Lam0LL_PTuple",
-        "Lam0LL_PbarTuple",
-        "Lam0LL_HPT_PTuple",
-        "Lam0LL_HPT_PbarTuple",
-        "Lam0LL_VHPT_PTuple",
-        "Lam0LL_VHPT_PbarTuple",
-    ],
-    "P_DD": [
-        "Lam0DD_PTuple",
-        "Lam0DD_PbarTuple",
-        "Lam0DD_HPT_PTuple",
-        "Lam0DD_HPT_PbarTuple",
-        "Lam0DD_VHPT_PTuple",
-        "Lam0DD_VHPT_PbarTuple",
-    ],
-    "P_Sigmac0": ["Sigmac0_PbarTuple", "Sigmac0_PTuple"],
-    "P_Sigmacpp": ["Sigmacpp_PbarTuple", "Sigmacpp_PTuple"],
-    "P_B_Jpsi": ["B_Jpsi_PTuple", "B_Jpsi_PbarTuple"],
-    "e_B_Jpsi": ["B_Jpsi_EPTuple", "B_Jpsi_EMTuple"],
-    "Mu_B_Jpsi": ["B_Jpsi_MuPTuple", "B_Jpsi_MuMTuple"],
-    "e": ["Jpsi_EPTuple", "Jpsi_EMTuple"],
-    "P_LcfB": ["LbLcMu_PTuple", "LbLcMu_PbarTuple"],
-    "P_IncLc": ["Lc_PTuple", "Lc_PbarTuple"],
-    "Mu_nopt": ["Jpsinopt_MuPTuple", "Jpsinopt_MuMTuple"],
-}
-
-simple_samples = [
-    "13b",
-    "15",
-    "17",
-    "20",
-    "20_MCTuneV2",
-    "20_MCTunev3",
-    "20r1",
-    "20r1_MCTuneV2",
-    "21",
-    "21_MCTuneV4",
-    "21r1",
-    "21r1_MCTuneV4",
-    "22",
-    "23",
-    "23Val",
-    "23_MCTuneV1",
-    "26",
-    "5TeV",
-    "Electron15",
-    "Electron16",
-    "Electron17",
-    "Electron18",
-]
-
-aliases = {
-    "DLLK": "probe_PIDK",
-    "DLLp": "probe_PIDp",
-    "DLLmu": "probe_PIDmu",
-    "DLLe": "probe_PIDe",
-    "DLLd": "probe_PIDd",
-    "MC12TuneV2_ProbNNe": "probe_MC12TuneV2_ProbNNe",
-    "MC12TuneV2_ProbNNmu": "probe_MC12TuneV2_ProbNNmu",
-    "MC12TuneV2_ProbNNghost": "probe_MC12TuneV2_ProbNNghost",
-    "MC12TuneV2_ProbNNk": "probe_MC12TuneV2_ProbNNk",
-    "MC12TuneV2_ProbNNp": "probe_MC12TuneV2_ProbNNp",
-    "MC12TuneV2_ProbNNpi": "probe_MC12TuneV2_ProbNNpi",
-    "MC12TuneV3_ProbNNe": "probe_MC12TuneV3_ProbNNe",
-    "MC12TuneV3_ProbNNmu": "probe_MC12TuneV3_ProbNNmu",
-    "MC12TuneV3_ProbNNghost": "probe_MC12TuneV3_ProbNNghost",
-    "MC12TuneV3_ProbNNk": "probe_MC12TuneV3_ProbNNk",
-    "MC12TuneV3_ProbNNp": "probe_MC12TuneV3_ProbNNp",
-    "MC12TuneV3_ProbNNpi": "probe_MC12TuneV3_ProbNNpi",
-    "MC12TuneV4_ProbNNe": "probe_MC12TuneV4_ProbNNe",
-    "MC12TuneV4_ProbNNmu": "probe_MC12TuneV4_ProbNNmu",
-    "MC12TuneV4_ProbNNghost": "probe_MC12TuneV4_ProbNNghost",
-    "MC12TuneV4_ProbNNk": "probe_MC12TuneV4_ProbNNk",
-    "MC12TuneV4_ProbNNp": "probe_MC12TuneV4_ProbNNp",
-    "MC12TuneV4_ProbNNpi": "probe_MC12TuneV4_ProbNNpi",
-    "MC15TuneV1_ProbNNe": "probe_MC15TuneV1_ProbNNe",
-    "MC15TuneV1_ProbNNmu": "probe_MC15TuneV1_ProbNNmu",
-    "MC15TuneV1_ProbNNghost": "probe_MC15TuneV1_ProbNNghost",
-    "MC15TuneV1_ProbNNk": "probe_MC15TuneV1_ProbNNk",
-    "MC15TuneV1_ProbNNp": "probe_MC15TuneV1_ProbNNp",
-    "MC15TuneV1_ProbNNpi": "probe_MC15TuneV1_ProbNNpi",
-    "Brunel_MC12TuneV2_ProbNNe": "probe_Brunel_MC12TuneV2_ProbNNe",
-    "Brunel_MC12TuneV2_ProbNNmu": "probe_Brunel_MC12TuneV2_ProbNNmu",
-    "Brunel_MC12TuneV2_ProbNNghost": "probe_Brunel_MC12TuneV2_ProbNNghost",
-    "Brunel_MC12TuneV2_ProbNNk": "probe_Brunel_MC12TuneV2_ProbNNk",
-    "Brunel_MC12TuneV2_ProbNNp": "probe_Brunel_MC12TuneV2_ProbNNp",
-    "Brunel_MC12TuneV2_ProbNNpi": "probe_Brunel_MC12TuneV2_ProbNNpi",
-    "Brunel_MC12TuneV3_ProbNNe": "probe_Brunel_MC12TuneV3_ProbNNe",
-    "Brunel_MC12TuneV3_ProbNNmu": "probe_Brunel_MC12TuneV3_ProbNNmu",
-    "Brunel_MC12TuneV3_ProbNNghost": "probe_Brunel_MC12TuneV3_ProbNNghost",
-    "Brunel_MC12TuneV3_ProbNNk": "probe_Brunel_MC12TuneV3_ProbNNk",
-    "Brunel_MC12TuneV3_ProbNNp": "probe_Brunel_MC12TuneV3_ProbNNp",
-    "Brunel_MC12TuneV3_ProbNNpi": "probe_Brunel_MC12TuneV3_ProbNNpi",
-    "Brunel_MC12TuneV4_ProbNNe": "probe_Brunel_MC12TuneV4_ProbNNe",
-    "Brunel_MC12TuneV4_ProbNNmu": "probe_Brunel_MC12TuneV4_ProbNNmu",
-    "Brunel_MC12TuneV4_ProbNNghost": "probe_Brunel_MC12TuneV4_ProbNNghost",
-    "Brunel_MC12TuneV4_ProbNNk": "probe_Brunel_MC12TuneV4_ProbNNk",
-    "Brunel_MC12TuneV4_ProbNNp": "probe_Brunel_MC12TuneV4_ProbNNp",
-    "Brunel_MC12TuneV4_ProbNNpi": "probe_Brunel_MC12TuneV4_ProbNNpi",
-    "Brunel_MC15TuneV1_ProbNNe": "probe_Brunel_MC15TuneV1_ProbNNe",
-    "Brunel_MC15TuneV1_ProbNNmu": "probe_Brunel_MC15TuneV1_ProbNNmu",
-    "Brunel_MC15TuneV1_ProbNNghost": "probe_Brunel_MC15TuneV1_ProbNNghost",
-    "Brunel_MC15TuneV1_ProbNNk": "probe_Brunel_MC15TuneV1_ProbNNk",
-    "Brunel_MC15TuneV1_ProbNNp": "probe_Brunel_MC15TuneV1_ProbNNp",
-    "Brunel_MC15TuneV1_ProbNNpi": "probe_Brunel_MC15TuneV1_ProbNNpi",
-    "P": "probe_P",
-    "Brunel_P": "probe_Brunel_P",
-    "PT": "probe_PT",
-    "Brunel_PT": "probe_Brunel_PT",
-    "ETA": "probe_ETA",
-    "Brunel_ETA": "probe_Brunel_ETA",
-    "nTracks": "nTracks",
-    "nTracks_Brunel": "nTracks_Brunel",
-    "nSPDhits": "nSPDhits",
-    "nSPDhits_Brunel": "nSPDhits_Brunel",
-    "TRCHI2NDOF": "probe_TRCHI2NDOF",
-    "Brunel_TRCHI2NDOF": "probe_Brunel_TRCHI2NDOF",
-    "IsMuon": "probe_isMuon",
-    "Brunel_IsMuon": "probe_Brunel_isMuon",
-    "HasRich": "probe_hasRich",
-    "Brunel_HasRich": "probe_Brunel_hasRich",
-    "IPCHI2": "probe_IPCHI2",
-    "Brunel_IPCHI2": "probe_Brunel_IPCHI2",
-    "TRACK_GHOSTPROB": "probe_TRACK_GHOSTPROB",
-    "Brunel_TRACK_GHOSTPROB": "probe_Brunel_TRACK_GHOSTPROB",
-}
+from .aliases import aliases
+from .samples import tuple_names, simple_samples
 
 
 def is_simple(sample: str) -> bool:
@@ -465,15 +327,13 @@ def get_tree_paths(
         # Run 1 (and Run 2 Electron) files have a simple structure with a single
         # tree
         tree_paths.append("DecayTree")
+    elif override_tuple_names and particle in override_tuple_names:
+        log.debug("Tree paths overriden by tuple_names")
+        for tuple_name in override_tuple_names[particle]:
+            tree_paths.append(f"{tuple_name}/DecayTree")
     else:
-        # Run 2 ROOT file structure with multiple trees
-        if override_tuple_names and particle in override_tuple_names:
-            log.debug("Tree paths overriden by tuple_names")
-            for tuple_name in override_tuple_names[particle]:
-                tree_paths.append(f"{tuple_name}/DecayTree")
-        else:
-            for tuple_name in tuple_names[particle]:
-                tree_paths.append(f"{tuple_name}/DecayTree")
+        for tuple_name in tuple_names[particle]:
+            tree_paths.append(f"{tuple_name}/DecayTree")
 
     return tree_paths
 
@@ -536,9 +396,6 @@ def get_calib_hists(
         whitespace = re.compile(r"\s+")
         pid_cut = re.sub(whitespace, "", pid_cut)
 
-        bin_str = ""
-        for bin_var in bin_vars:
-            bin_str += f"_{bin_var}"
         calib_name = Path(
             hist_dir,
             utils.create_hist_filename(
